@@ -17,15 +17,23 @@ struct SLayoutMessageHeader {
 
 enum eFullscreenMode : int8_t;
 
-enum eRectCorner {
-    CORNER_NONE = 0,
-    CORNER_TOPLEFT,
-    CORNER_TOPRIGHT,
-    CORNER_BOTTOMRIGHT,
-    CORNER_BOTTOMLEFT
+enum eRectCorner : uint8_t {
+    CORNER_NONE        = 0,
+    CORNER_TOPLEFT     = (1 << 0),
+    CORNER_TOPRIGHT    = (1 << 1),
+    CORNER_BOTTOMRIGHT = (1 << 2),
+    CORNER_BOTTOMLEFT  = (1 << 3),
 };
 
-enum eDirection {
+enum eSnapEdge : uint8_t {
+    SNAP_INVALID = 0,
+    SNAP_UP      = (1 << 0),
+    SNAP_DOWN    = (1 << 1),
+    SNAP_LEFT    = (1 << 2),
+    SNAP_RIGHT   = (1 << 3),
+};
+
+enum eDirection : int8_t {
     DIRECTION_DEFAULT = -1,
     DIRECTION_UP      = 0,
     DIRECTION_RIGHT,
